@@ -1,6 +1,6 @@
 #! /usr/bin/perl -w
 
-#    Copyright (C) 2004-2024 Simon Josefsson
+#    Copyright (C) 2004-2025 Simon Josefsson
 #    Copyright (C) 1998, 1999 Tom Tromey
 #    Copyright (C) 2001 Red Hat Software
 
@@ -34,6 +34,8 @@
 # we use some perl unicode features
 require 5.006;
 
+use bytes;
+
 use vars qw($CODE $NAME $CATEGORY $COMBINING_CLASSES $BIDI_CATEGORY $DECOMPOSITION $DECIMAL_VALUE $DIGIT_VALUE $NUMERIC_VALUE $MIRRORED $OLD_NAME $COMMENT $UPPER $LOWER $TITLE $BREAK_CODE $BREAK_CATEGORY $BREAK_NAME $CASE_CODE $CASE_LOWER $CASE_TITLE $CASE_UPPER $CASE_CONDITION);
 
 
@@ -169,10 +171,10 @@ elsif (@ARGV && $ARGV[0] eq '-both')
 
 if (@ARGV != 2) {
     $0 =~ s@.*/@@;
-    die "\nUsage: $0 [-decomp | -both] UNICODE-VERSION DIRECTORY\n\n       DIRECTORY should contain the following Unicode data files:\n       UnicodeData.txt, LineBreak.txt, SpecialCasing.txt, CaseFolding.txt,\n       CompositionExclusions.txt, BidiMirroring.txt\n\n";
+    die "\nUsage: $0 [-decomp | -both] UNICODE-VERSION DIRECTORY\n\n       DIRECTORY should contain the following Unicode data files:\n       UnicodeData.txt, LineBreak.txt, SpecialCasing.txt, CaseFolding.txt,\n       CompositionExclusions.txt\n\n";
 }
 
-my ($unicodedatatxt, $linebreaktxt, $specialcasingtxt, $casefoldingtxt, $compositionexclusionstxt, $bidimirroringtxt);
+my ($unicodedatatxt, $linebreaktxt, $specialcasingtxt, $casefoldingtxt, $compositionexclusionstxt);
 
 my $d = $ARGV[1];
 opendir (my $dir, $d) or die "Cannot open Unicode data dir $d: $!\n";
@@ -183,7 +185,6 @@ for my $f (readdir ($dir))
     $specialcasingtxt = "$d/$f" if ($f =~ /SpecialCasing.*\.txt/);
     $casefoldingtxt = "$d/$f" if ($f =~ /CaseFolding.*\.txt/);
     $compositionexclusionstxt = "$d/$f" if ($f =~ /CompositionExclusions.*\.txt/);
-    $bidimirroringtxt = "$d/$f" if ($f =~ /BidiMirroring.*\.txt/);
 }
 
 defined $unicodedatatxt or die "Did not find UnicodeData file";
@@ -191,7 +192,6 @@ defined $linebreaktxt or die "Did not find LineBreak file";
 defined $specialcasingtxt or die "Did not find SpecialCasing file";
 defined $casefoldingtxt or die "Did not find CaseFolding file";
 defined $compositionexclusionstxt or die "Did not find CompositionExclusions file";
-defined $bidimirroringtxt or die "Did not find BidiMirroring file";
 
 print "Creating decomp table\n" if ($do_decomp);
 print "Creating property table\n" if ($do_props);
@@ -482,23 +482,6 @@ while (<INPUT>)
 
 close INPUT;
 
-open (INPUT, "< $bidimirroringtxt") || exit 1;
-
-my @bidimirror;
-while (<INPUT>)
-{
-    chomp;
-
-    next if /^#/;
-    next if /^\s*$/;
-
-    s/\s*#.*//;
-
-    @fields = split ('\s*;\s*', $_, 30);
-
-    push @bidimirror, [hex ($fields[0]), hex ($fields[1])];
-}
- 
 if ($do_props) {
     &print_tables ($last_code)
 }
@@ -517,7 +500,6 @@ sub length_in_bytes
 {
     my ($string) = @_;
 
-    use bytes;
     return length $string;
 }
 
@@ -675,21 +657,6 @@ sub print_tables
     &output_special_case_table (\*OUT);
     &output_casefold_table (\*OUT);
 
-    print OUT "static const struct {\n";
-    print OUT "    gunichar ch;\n";
-    print OUT "    gunichar mirrored_ch;\n";
-    print OUT "} bidi_mirroring_table[] =\n";
-    print OUT "{\n";
-    $first = 1;
-    foreach $item (@bidimirror)
-    {
-        print OUT ",\n" unless $first;
-        $first = 0;
-        printf OUT "  { 0x%04x, 0x%04x }", $item->[0], $item->[1];
-        $bytes_out += 8;
-    }
-    print OUT "\n};\n\n";
-
     print OUT "#endif /* CHARTABLES_H */\n";
 
     close (OUT);
