@@ -1,5 +1,5 @@
 /* tst_punycode.c --- Self tests for punycode.
- * Copyright (C) 2002-2024 Simon Josefsson
+ * Copyright (C) 2002-2025 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -40,7 +40,7 @@ struct punycode
   int rc;
 };
 
-const struct punycode punycode[] = {
+static const struct punycode punycode[] = {
   {
    "(A) Arabic (Egyptian)", 17,
    {
