@@ -1,5 +1,5 @@
 /* tst_tld.c --- Self tests for tld_*().
- * Copyright (C) 2004-2024 Simon Josefsson
+ * Copyright (C) 2004-2025 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -70,7 +70,7 @@ static const Tld_table _tld_fr_override = {
 };
 
 /* Main array */
-const Tld_table *my_tld_tables[] = {
+static const Tld_table *my_tld_tables[] = {
   &_tld_fr_override,
   NULL
 };
